package com.ruoyi.web.modules.technology.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Param;
import com.ruoyi.web.modules.technology.domain.BizPracticalTraining;

/**
 * 实战业务培训 Mapper
 */
public interface BizPracticalTrainingMapper
{
    BizPracticalTraining selectBizPracticalTrainingById(Long id);

    BizPracticalTraining selectBizPracticalTrainingByIdAny(Long id);

    List<BizPracticalTraining> selectBizPracticalTrainingList(BizPracticalTraining query);

    int insertBizPracticalTraining(BizPracticalTraining row);

    int updateBizPracticalTraining(BizPracticalTraining row);

    int logicDeleteBizPracticalTrainingByIds(@Param("ids") Long[] ids, @Param("updateBy") String updateBy);

    BizPracticalTraining selectPublishedBizPracticalTrainingById(Long id);

    int updateTrainingStatusAndCount(BizPracticalTraining row);
}
